Module: Mongrel::HttpHandlerPlugin

Overview

This is used when your handler is implemented as a GemPlugin. The plugin always takes an options hash which you can modify and then access later. They are stored by default for the process method later.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#listenerObject

Returns the value of attribute listener.



53
54
55
# File 'lib/mongrel/handlers.rb', line 53

def listener
  @listener
end

#optionsObject (readonly)

Returns the value of attribute options.



51
52
53
# File 'lib/mongrel/handlers.rb', line 51

def options
  @options
end

#request_notifyObject (readonly)

Returns the value of attribute request_notify.



52
53
54
# File 'lib/mongrel/handlers.rb', line 52

def request_notify
  @request_notify
end

Instance Method Details

#initialize(options = {}) ⇒ Object



61
62
63
64
# File 'lib/mongrel/handlers.rb', line 61

def initialize(options={})
  @options = options
  @header_only = false
end

#process(request, response) ⇒ Object



66
67
# File 'lib/mongrel/handlers.rb', line 66

def process(request, response)
end

#request_begins(params) ⇒ Object



55
56
# File 'lib/mongrel/handlers.rb', line 55

def request_begins(params)
end

#request_progress(params, clen, total) ⇒ Object



58
59
# File 'lib/mongrel/handlers.rb', line 58

def request_progress(params, clen, total)
end